@@ -30,8 +30,6 @@ env = environ.Env(
     DEFENDER_ENABLED=(bool, False),
     EDC_RANDOMIZATION_REGISTER_DEFAULT_RANDOMIZER=(bool, True),
     EDC_LABEL_BROWSER_PRINT_PAGE_AUTO_BACK=(bool, True),
-    SIMPLE_HISTORY_PERMISSIONS_ENABLED=(bool, False),
-    SIMPLE_HISTORY_REVERT_DISABLED=(bool, False),
     TWILIO_ENABLED=(bool, False),
 )
 
@@ -391,9 +389,6 @@ EDC_RANDOMIZATION_SKIP_VERIFY_CHECKS = True
 # edc-sites
 EDC_SITES_MODULE_NAME = env.str("EDC_SITES_MODULE_NAME")
 
-# django-simple-history
-SIMPLE_HISTORY_REVERT_ENABLED = False
-
 # django-multisite
 CACHE_MULTISITE_KEY_PREFIX = APP_NAME
 SILENCED_SYSTEM_CHECKS = ["sites.E101"]
@@ -436,7 +431,6 @@ AUTO_CREATE_KEYS = env("DJANGO_AUTO_CREATE_KEYS")
 EXPORT_FOLDER = env.str("DJANGO_EXPORT_FOLDER") or os.path.expanduser("~/")
 
 # django_simple_history
-SIMPLE_HISTORY_REVERT_DISABLED = False
 SIMPLE_HISTORY_ENFORCE_HISTORY_MODEL_PERMISSIONS = True
 
 FQDN = env.str("DJANGO_FQDN")  # ???
