@@ -3,11 +3,12 @@ from typing import Tuple
 from dateutil.relativedelta import relativedelta
 from django.contrib import admin
 from django.utils.html import format_html
-from edc_action_item import action_fieldset_tuple
+from django_audit_fields.admin import audit_fieldset_tuple
+from edc_action_item import ActionItemModelAdminMixin, action_fieldset_tuple
 from edc_constants.constants import OTHER
 from edc_data_manager.modeladmin_mixins import DataManagerModelAdminMixin
-from edc_model_admin import SimpleHistoryAdmin, audit_fieldset_tuple
 from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
+from edc_model_admin.history import SimpleHistoryAdmin
 
 from meta_ae.models import DeathReport
 from meta_consent.models import SubjectConsent
@@ -21,6 +22,7 @@ from ..models import EndOfStudy, LossToFollowup
 class EndOfStudyAdmin(
     DataManagerModelAdminMixin,
     ModelAdminSubjectDashboardMixin,
+    ActionItemModelAdminMixin,
     SimpleHistoryAdmin,
 ):
 
