@@ -1,5 +1,5 @@
 from django.contrib.auth.models import User
-from django.test import TestCase, tag
+from django.test import TestCase
 from django.test.client import RequestFactory
 from edc_adverse_event.models import AeClassification
 from model_bakery import baker
@@ -10,9 +10,7 @@ from meta_screening.tests.meta_test_case_mixin import MetaTestCaseMixin
 
 class TestReports(MetaTestCaseMixin, TestCase):
     def setUp(self):
-        self.user = User.objects.create(
-            username="erikvw", is_staff=True, is_active=True
-        )
+        self.user = User.objects.create(username="erikvw", is_staff=True, is_active=True)
         subject_screening = self.get_subject_screening()
         subject_consent = self.get_subject_consent(subject_screening)
         self.subject_identifier = subject_consent.subject_identifier
