@@ -1,5 +1,6 @@
 from django.contrib import admin
-from edc_model_admin import SimpleHistoryAdmin, audit_fieldset_tuple
+from django_audit_fields.admin import audit_fieldset_tuple
+from edc_model_admin.history import SimpleHistoryAdmin
 from edc_visit_schedule.fieldsets import visit_schedule_fieldset_tuple
 from edc_visit_tracking.modeladmin_mixins import VisitModelAdminMixin
 
