@@ -1,5 +1,5 @@
 from django import forms
-from edc_action_item.forms.action_item_form_mixin import ActionItemFormMixin
+from edc_action_item.forms import ActionItemCrfFormMixin
 from edc_constants.constants import CLOSED, NEW, OPEN
 from edc_crf.modelform_mixins import CrfModelFormMixin
 from edc_form_validators import INVALID_ERROR
@@ -17,10 +17,10 @@ class EgfrDropNotificationFormValidator(FormValidator):
             )
 
 
-class EgfrDropNotificationForm(CrfModelFormMixin, ActionItemFormMixin, forms.ModelForm):
+class EgfrDropNotificationForm(CrfModelFormMixin, ActionItemCrfFormMixin, forms.ModelForm):
 
     form_validator_cls = EgfrDropNotificationFormValidator
 
-    class Meta(ActionItemFormMixin.Meta):
+    class Meta(ActionItemCrfFormMixin.Meta):
         model = EgfrDropNotification
         fields = "__all__"
