@@ -1,4 +1,5 @@
 from django import forms
+from edc_constants.constants import YES
 from edc_crf.modelform_mixins import CrfModelFormMixin
 from edc_form_validators import INVALID_ERROR
 from edc_pharmacy.form_validators import (
@@ -18,7 +19,7 @@ class StudyMedicationFormValidator(BaseStudyMedicationFormValidator):
         """Require 1000mg dose at baseline"""
         try:
             subject_visit = (
-                self.cleaned_data.get("subject_visit") or self.instance.subject_visit
+                self.cleaned_data.get("subject_visit") or self.instance.related_visit
             )
         except AttributeError:
             self.raise_validation_error("Subject visit is required", INVALID_ERROR)
@@ -36,6 +37,15 @@ class StudyMedicationForm(CrfModelFormMixin, forms.ModelForm):
 
     form_validator_cls = StudyMedicationFormValidator
 
+    def clean(self):
+        if (
+            not self.cleaned_data.get("refill_end_datetime")
+            and self.cleaned_data.get("refill_to_next_visit") == YES
+        ):
+            if next_appt := self.subject_visit.appointment.relative_next:
+                self.cleaned_data["refill_end_datetime"] = next_appt.appt_datetime
+        return super().clean()
+
     class Meta:
         model = StudyMedication
         fields = "__all__"
