@@ -13,7 +13,7 @@ from .complications_glycemia import ComplicationsGlycemia
 from .concomitant_medication import ConcomitantMedication
 from .delivery import Delivery
 from .diet_and_lifestyle import DietAndLifestyle
-from .egfr_notification import EgfrNotification
+from .egfr_drop_notification import EgfrDropNotification
 from .eq5d3l import Eq5d3l
 from .followup_examination import FollowupExamination
 from .followup_vitals import FollowupVitals
